@@ -220,7 +220,12 @@ EOF
     test -e pkg/$f || cp -a $HOME/Development/MinGW_Packages/$f pkg/
   done
   echo "### Build docker image"
-  docker build -t ufleisch/kid3dev . -f-<<EOF
+  if hash podman 2>/dev/null; then
+    DOCKER=podman
+  else
+    DOCKER=docker
+  fi
+  $DOCKER build -t ufleisch/kid3dev . -f-<<EOF
 FROM ubuntu:18.04
 RUN apt-get update && apt-get install -y --no-install-recommends \
 devscripts build-essential lintian debhelper extra-cmake-modules \
@@ -249,7 +254,14 @@ fi
 if test "$1" = "rundocker"; then
   echo "### Run docker image"
   shift
-  docker run --rm -it -e LANG=C.UTF-8 \
+  if hash podman 2>/dev/null; then
+    DOCKER=podman
+    USERNSARG=--userns=keep-id
+  else
+    DOCKER=docker
+    USERNSARG=
+  fi
+  $DOCKER run $USERNSARG --rm -it -e LANG=C.UTF-8 \
          -v $HOME/projects/kid3:$HOME/projects/kid3 \
          -v $HOME/.gradle:$HOME/.gradle \
          -v $HOME/.gnupg:$HOME/.gnupg:ro \
@@ -451,7 +463,7 @@ if test $kernel = "Darwin"; then
   else
     ARCH_FLAG="-Xarch_x86_64"
   fi
-  if [[ $(sw_vers -productVersion) = 10.1* ]]; then
+  if [[ $(sw_vers -productVersion) = 10.1* || $(sw_vers -productVersion) = 11.* ]]; then
     CMAKE_OPTIONS="$CMAKE_OPTIONS -DCMAKE_C_FLAGS=\"-O2 $ARCH_FLAG -mmacosx-version-min=10.7\" -DCMAKE_CXX_FLAGS=\"-O2 $ARCH_FLAG -mmacosx-version-min=10.7 -fvisibility=hidden -fvisibility-inlines-hidden -stdlib=libc++\" -DCMAKE_EXE_LINKER_FLAGS=\"$ARCH_FLAG -stdlib=libc++\" -DCMAKE_MODULE_LINKER_FLAGS=\"$ARCH_FLAG -stdlib=libc++\" -DCMAKE_SHARED_LINKER_FLAGS=\"$ARCH_FLAG -stdlib=libc++\""
     export CFLAGS="-O2 $ARCH_FLAG -mmacosx-version-min=10.7"
     export CXXFLAGS="-O2 $ARCH_FLAG -mmacosx-version-min=10.7 -stdlib=libc++"
