@@ -216,7 +216,8 @@ Kid3Cli::Kid3Cli(Kid3Application* app,
          << new TagToOtherTagCommand(this)
          << new CopyCommand(this)
          << new PasteCommand(this)
-         << new RemoveCommand(this);
+         << new RemoveCommand(this)
+         << new ConfigCommand(this);
   connect(m_app, &Kid3Application::fileSelectionUpdateRequested,
           this, &Kid3Cli::updateSelectedFiles);
   connect(m_app, &Kid3Application::selectedFilesUpdated,
@@ -376,7 +377,7 @@ QStringList Kid3Cli::expandWildcards(const QStringList& paths)
   QStringList expandedPaths;
   for (const QString& path : paths) {
     QStringList expandedPath;
-    int wcIdx = path.indexOf(QRegExp(QLatin1String("[?*]")));
+    int wcIdx = path.indexOf(QRegularExpression(QLatin1String("[?*]")));
     if (wcIdx != -1) {
       QString partBefore, partAfter;
       int beforeIdx = path.lastIndexOf(QDir::separator(), wcIdx);
@@ -647,6 +648,15 @@ void Kid3Cli::writeResult(const QVariantMap& map)
   m_formatter->writeResult(map);
 }
 
+/**
+ * Write result of command.
+ * @param result result as boolean
+ */
+void Kid3Cli::writeResult(bool result)
+{
+  m_formatter->writeResult(result);
+}
+
 /**
  * Called when a command is finished.
  */
